verify

Function verify 

pub fn verify<const M: usize, R: RngCore>(
    data: Data<'_>,
    commitment: &Commitment,
    challenge: &Challenge<M>,
    proof: &Proof<M>,
    rng: &mut R,
) -> Result<(), InvalidProof>
Verify the proof. If this succeeds, the relation Rmod holds with chance 1/2^M

Rng is used for primality checking of input data